diff --git a/src/mapi/glapi/gen/ARB_bindless_texture.xml b/src/mapi/glapi/gen/ARB_bindless_texture.xml
index 79be451c758..0c9167594b2 100644
--- a/src/mapi/glapi/gen/ARB_bindless_texture.xml
+++ b/src/mapi/glapi/gen/ARB_bindless_texture.xml
@@ -79,12 +79,12 @@
-
+
-
+
diff --git a/src/mapi/glapi/gen/ARB_vertex_attrib_64bit.xml b/src/mapi/glapi/gen/ARB_vertex_attrib_64bit.xml
index 75d7468ac6f..c9b75c5f03c 100644
--- a/src/mapi/glapi/gen/ARB_vertex_attrib_64bit.xml
+++ b/src/mapi/glapi/gen/ARB_vertex_attrib_64bit.xml
@@ -5,25 +5,25 @@
-
+
-
+
-
+
-
+
@@ -31,22 +31,22 @@
-
+
-
+
-
+
-
+
diff --git a/src/mapi/glapi/gen/ARB_vertex_type_2_10_10_10_rev.xml b/src/mapi/glapi/gen/ARB_vertex_type_2_10_10_10_rev.xml
index 282621f22fe..719bc7966c4 100644
--- a/src/mapi/glapi/gen/ARB_vertex_type_2_10_10_10_rev.xml
+++ b/src/mapi/glapi/gen/ARB_vertex_type_2_10_10_10_rev.xml
@@ -7,214 +7,214 @@
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
diff --git a/src/mapi/glapi/gen/EXT_gpu_shader4.xml b/src/mapi/glapi/gen/EXT_gpu_shader4.xml
index 1561d97af4c..b829319ed6f 100644
--- a/src/mapi/glapi/gen/EXT_gpu_shader4.xml
+++ b/src/mapi/glapi/gen/EXT_gpu_shader4.xml
@@ -40,25 +40,25 @@
-
+
-
+
-
+
-
+
@@ -66,25 +66,25 @@
-
+
-
+
-
+
-
+
@@ -97,17 +97,17 @@
-
+
-
+
-
+
@@ -117,17 +117,17 @@
-
+
-
+
-
+
diff --git a/src/mapi/glapi/gen/GL3x.xml b/src/mapi/glapi/gen/GL3x.xml
index 75307d78c0a..e6fd27b9a0d 100644
--- a/src/mapi/glapi/gen/GL3x.xml
+++ b/src/mapi/glapi/gen/GL3x.xml
@@ -330,7 +330,7 @@
-
+
@@ -350,7 +350,7 @@
-
+
@@ -370,22 +370,22 @@
-
+
-
+
-
+
-
+
diff --git a/src/mapi/glapi/gen/NV_half_float.xml b/src/mapi/glapi/gen/NV_half_float.xml
index 40965bd10e6..30d56923e55 100644
--- a/src/mapi/glapi/gen/NV_half_float.xml
+++ b/src/mapi/glapi/gen/NV_half_float.xml
@@ -5,139 +5,139 @@
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
@@ -145,45 +145,45 @@
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
@@ -191,50 +191,50 @@
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
diff --git a/src/mapi/glapi/gen/NV_primitive_restart.xml b/src/mapi/glapi/gen/NV_primitive_restart.xml
index e53062f78ea..eaed2f7c46e 100644
--- a/src/mapi/glapi/gen/NV_primitive_restart.xml
+++ b/src/mapi/glapi/gen/NV_primitive_restart.xml
@@ -11,7 +11,7 @@
-
+
diff --git a/src/mapi/glapi/gen/api_exec_init.py b/src/mapi/glapi/gen/api_exec_init.py
index 35ac3bb889c..b7ad95dd7e5 100644
--- a/src/mapi/glapi/gen/api_exec_init.py
+++ b/src/mapi/glapi/gen/api_exec_init.py
@@ -33,7 +33,7 @@ import apiexec
exec_flavor_map = {
- 'vtxfmt': None,
+ 'beginend': None,
'dlist': '_mesa_',
'mesa': '_mesa_',
'skip': None,
@@ -105,7 +105,7 @@ class PrintCode(gl_XML.gl_print_base):
prefix = exec_flavor_map[f.exec_flavor]
if prefix is None:
# This function is not implemented, or is dispatched
- # via vtxfmt.
+ # via beginend.
continue
if f.has_no_error_variant:
no_error_condition = '_mesa_is_no_error_enabled(ctx) && ({0})'.format(condition)
diff --git a/src/mapi/glapi/gen/api_hw_select_init_h.py b/src/mapi/glapi/gen/api_hw_select_init_h.py
index ae8cdda2c1c..8d2e851f9c1 100644
--- a/src/mapi/glapi/gen/api_hw_select_init_h.py
+++ b/src/mapi/glapi/gen/api_hw_select_init_h.py
@@ -43,7 +43,7 @@ class PrintCode(gl_XML.gl_print_base):
def printBody(self, api):
for f in api.functionIterateAll():
- if f.exec_flavor != 'vtxfmt':
+ if f.exec_flavor != 'beginend':
continue
if (re.match('Vertex*', f.name)):
diff --git a/src/mapi/glapi/gen/gl_API.xml b/src/mapi/glapi/gen/gl_API.xml
index 35bbac8c8d1..fc69c152c0b 100644
--- a/src/mapi/glapi/gen/gl_API.xml
+++ b/src/mapi/glapi/gen/gl_API.xml
@@ -1122,12 +1122,12 @@
-
+
-
@@ -1155,7 +1155,7 @@
-
@@ -1173,157 +1173,157 @@
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
@@ -1331,139 +1331,139 @@
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
-
+
-
+
+ exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
@@ -1652,309 +1652,309 @@
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
@@ -2080,14 +2080,14 @@
-
+
-
+
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
-
+
@@ -2545,7 +2545,7 @@
-
+
@@ -2559,7 +2559,7 @@
-
+
@@ -3188,7 +3188,7 @@
-
+
@@ -3408,11 +3408,11 @@
-
+
-
+
@@ -4327,12 +4327,12 @@
-
+
-
+
@@ -4349,35 +4349,35 @@
-
+
-
+
-
+
-
+
-
+
-
+
@@ -4396,38 +4396,38 @@
-
+
-
+
-
+
-
+
-
+
-
+
@@ -4447,33 +4447,33 @@
-
+
-
+
-
+
-
+
-
+
@@ -4481,7 +4481,7 @@
-
+
@@ -4502,7 +4502,7 @@
-
+
@@ -4510,13 +4510,13 @@
-
+
-
+
@@ -4524,7 +4524,7 @@
-
+
@@ -4777,11 +4777,11 @@
-
+
-
+
@@ -4837,91 +4837,91 @@
-
+
-
+
-
+
-
+
+ deprecated="3.1" exec="beginend">
+ deprecated="3.1" exec="beginend">
-
+
-
+
-
+
-
+
-
+
-
+
-
+
diff --git a/src/mapi/glapi/gen/api_vtxfmt_init_h.py b/src/mapi/glapi/gen/api_beginend_init_h.py
similarity index 95%
rename from src/mapi/glapi/gen/api_vtxfmt_init_h.py
rename to src/mapi/glapi/gen/api_beginend_init_h.py
index 6bd9bb1f107..b0aab7b5f81 100644
--- a/src/mapi/glapi/gen/api_vtxfmt_init_h.py
+++ b/src/mapi/glapi/gen/api_beginend_init_h.py
@@ -20,7 +20,7 @@
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.
# This script generates the file api_vtxfmt_init.h.
import argparse
import collections
@@ -35,7 +35,7 @@ class PrintCode(gl_XML.gl_print_base):
def __init__(self):
super().__init__()
- self.name = 'api_vtxfmt_init_h.py'
+ self.name = 'api_beginend_init_h.py'
self.license = license.bsd_license_template % (
'Copyright (C) 2012 Intel Corporation\n'
'Copyright (C) 2021 Advanced Micro Devices, Inc.',
@@ -47,7 +47,7 @@ class PrintCode(gl_XML.gl_print_base):
settings_by_condition = collections.defaultdict(lambda: [])
for f in api.functionIterateAll():
- if f.exec_flavor != 'vtxfmt':
+ if f.exec_flavor != 'beginend':
continue
condition = apiexec.get_api_condition(f)
@@ -20,7 +20,7 @@
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.
-# This script generates the file api_vtxfmt_init.h.
+# This script generates the file api_beginend_init.h.
import argparse
import collections